# 2021-08-12 - Lido Relayer

Deployment of the `LidoRelayer`, for using stETH with the Balancer Vault without having to wrap to wstETH separately.

## Useful Files

- [Ethereum mainnet addresses](./output/mainnet.json)
- [`LidoRelayer` ABI](./abi/LidoRelayer.json)
